:mod:`art.estimators.certification.randomized_smoothing`
========================================================
.. automodule:: art.estimators.certification.randomized_smoothing

Mixin Base Class Randomized Smoothing
-------------------------------------
.. autoclass:: RandomizedSmoothingMixin
   :members:

PyTorch Randomized Smoothing Classifier
---------------------------------------
.. autoclass:: PyTorchRandomizedSmoothing
   :members:
   :special-members: __init__
   :inherited-members:

TensorFlow V2 Randomized Smoothing Classifier
---------------------------------------------
.. autoclass:: TensorFlowV2RandomizedSmoothing
   :members:
   :special-members: __init__
   :inherited-members:
